@@ -59,7 +59,7 @@ function(cross, step=0, off.end=0, error.prob=0.0001,
   n.mar <- nmar(cross)
 
   type <- class(cross)[1]
-
+  
   # calculate genotype probabilities one chromosome at a time
   for(i in 1:n.chr) {
     if(n.mar[i]==1) temp.offend <- max(c(off.end,5))
@@ -112,6 +112,21 @@ function(cross, step=0, off.end=0, error.prob=0.0001,
       if(xchr)
         warning("calc.genoprob not working properly for the X chromosome for 4- or 8-way RIL.")
     }
+    else if(type == "bcsft") {
+      one.map <- TRUE
+      cfunc <- "calc_genoprob_bcsft"
+      cross.scheme <- attr(cross, "scheme") ## c(s,t) for BC(s)F(t)
+      if(!xchr) { # autosomal
+        gen.names <- getgenonames("bcsft", "A", cross.attr=attributes(cross))
+        n.gen <- 2 + (cross.scheme[2] > 0)
+      }
+      else { ## X chr
+        cross.scheme[1] <- cross.scheme[1] + cross.scheme[2] - (cross.scheme[1] == 0)
+        cross.scheme[2] <- 0
+        gen.names <- c("g1","g2")
+        n.gen <- 2
+      }
+    }
     else 
       stop("calc.genoprob not available for cross type ", type, ".")
 
@@ -151,16 +166,28 @@ function(cross, step=0, off.end=0, error.prob=0.0001,
       n.pos <- ncol(newgen)
       marnames <- colnames(map)
     }
+    ## Cross scheme being added for Ft and BCs.
+    ## cross_scheme = c(BC = s, F = t).
+    ## BC has cross_scheme = c(1,0)
+    ## F2 has cross_scheme = c(0,2)
+    ## BCsFt has cross_scheme = c(s,t)
+    ## Other designs such as Ft with test cross don't quite fit in (yet).
+    ## *** Need to change all the C routines!!
 
     # call the C function
     if(one.map) {
+      ## Hide cross scheme in genoprob to pass to routine. BY
+      temp <- as.double(rep(0,n.gen*n.ind*n.pos))
+      if(type == "bcsft")
+        temp[1:2] <- cross.scheme
+      
       z <- .C(cfunc,
               as.integer(n.ind),         # number of individuals
               as.integer(n.pos),         # number of markers
               as.integer(newgen),        # genotype data
               as.double(rf),             # recombination fractions
               as.double(error.prob),     # 
-              genoprob=as.double(rep(0,n.gen*n.ind*n.pos)),
+              genoprob=as.double(temp),
               PACKAGE="qtl")
     }
     else {
@@ -289,6 +316,27 @@ function(cross, error.prob=0.0001,
       if(xchr)
         warning("calc.genoprob.special not working properly for the X chromosome for 4- or 8-way RIL.")
     }
+    else if(type == "bcsft") {
+      one.map <- TRUE
+      cfunc <- "calc_genoprob_bcsft"
+      cross.scheme <- attr(cross, "scheme") ## c(s,t) for BC(s)F(t)
+      if(!xchr) { # autosomal
+        if(cross.scheme[2] == 0) {
+          gen.names <- getgenonames("bc", "A", cross.attr=attributes(cross))
+          n.gen <- 2
+        }
+        else {
+          gen.names <- getgenonames("f2", "A", cross.attr=attributes(cross))
+          n.gen <- 3
+        }
+      }
+      else { ## X chr
+        cross.scheme[1] <- cross.scheme[1] + cross.scheme[2] - (cross.scheme[1] == 0)
+        cross.scheme[2] <- 0
+        gen.names <- c("g1","g2")
+        n.gen <- 2
+      }
+    }
     else 
       stop("calc.genoprob.special not available for cross type ", type, ".")
 
@@ -331,13 +379,18 @@ function(cross, error.prob=0.0001,
 
     # call the C function
     if(one.map) {
-      z <- .C(cfunc,
+      ## Hide cross scheme in genoprob to pass to routine. BY
+      temp <- as.double(rep(0,n.gen*n.ind*n.pos))
+      if(type == "bcsft")
+        temp[1:2] <- cross.scheme
+      
+     z <- .C(cfunc,
               as.integer(n.ind),         # number of individuals
               as.integer(n.pos),         # number of markers
               as.integer(newgen),        # genotype data
               as.double(rf),             # recombination fractions
               as.double(error.prob),     # 
-              genoprob=as.double(rep(0,n.gen*n.ind*n.pos)),
+              genoprob=as.double(temp),
               PACKAGE="qtl")
     }
     else {
