@@ -3,7 +3,7 @@
 # readMWril.R
 #
 # copyright (c) 2009-2011, Karl W Broman
-# last modified May, 2011
+# last modified Dec, 2011
 # first written Apr, 2009
 #
 #     This program is free software; you can redistribute it and/or
@@ -35,8 +35,9 @@
 
 readMWril <-
 function(dir, rilfile, founderfile, 
-         type=c("ri4self", "ri4sib", "ri8self", "ri8sib"),
-         na.strings=c("-","NA"), rotate=FALSE, ...)
+         type=c("ri4self", "ri4sib", "ri8self", "ri8sib", "bgmagic16"),
+         na.strings=c("-","NA"), rotate=FALSE, 
+         ...)
 {
   # create file names
   if(missing(rilfile) || missing(founderfile))
@@ -205,9 +206,9 @@ function(dir, rilfile, founderfile,
   }
 
   wh <- which(is.na(gen))
-  themissing <- min(as.numeric(c(gen, founder)), na.rm=TRUE)-1
-  gen[wh] <- themissing
-  founder[is.na(founder)] <- themissing
+  missingval <- min(as.numeric(c(gen, founder)), na.rm=TRUE)-1
+  gen[wh] <- missingval
+  founder[is.na(founder)] <- missingval
   d <- dim(gen)
   gen <-
     .C("R_reviseMWril",
@@ -217,7 +218,7 @@ function(dir, rilfile, founderfile,
        as.integer(founder),
        gen=as.integer(gen),
        as.integer(crosses),
-       as.integer(themissing),
+       as.integer(missingval),
        PACKAGE="qtl")$gen
   gen[wh] <- NA
   gen <- matrix(gen, nrow=d[1])
@@ -297,6 +298,23 @@ function(dir, rilfile, founderfile,
     warning("There is no genotype data!\n")
 
   cross$cross <- crosses
+
+  # save founder genotypes in data
+  founder[founder==missingval] <- NA
+  ua <- apply(founder, 2, function(a) unique(a[!is.na(a)]))
+  nua <- sapply(ua, length)
+  if(all(nua <= 2)) { # re-code as 0/1
+    for(i in 1:ncol(founder)) {
+      if(nua[i]==1)
+        founder[!is.na(founder[,i]),i] <- 0
+      else if(nua[i]==2) {
+        founder[!is.na(founder[,i]) & founder[,i]==ua[[i]][1],i] <- 0
+        founder[!is.na(founder[,i]) & founder[,i]==ua[[i]][2],i] <- 1
+      }
+    }
+  }
+  cross$founderGeno <- founder
+
   class(cross) <- c(type, "cross")
 
   # check data
@@ -305,4 +323,5 @@ function(dir, rilfile, founderfile,
   cross
 }
 
+
 # end of readMWril.R
