@@ -75,9 +75,9 @@
 void calc_genoprob(int n_ind, int n_pos, int n_gen, int *geno, 
 		   double *rf, double *rf2, 
 		   double error_prob, double *genoprob, 
-		   double initf(int), 
-		   double emitf(int, int, double),
-		   double stepf(int, int, double, double));
+		   double initf(int, int *), 
+		   double emitf(int, int, double, int *),
+		   double stepf(int, int, double, double, int *));
 
 
 /**********************************************************************
@@ -96,9 +96,9 @@ void calc_genoprob(int n_ind, int n_pos, int n_gen, int *geno,
 void calc_genoprob_special(int n_ind, int n_pos, int n_gen, int *geno, 
 			   double *rf, double *rf2, 
 			   double error_prob, double *genoprob, 
-			   double initf(int), 
-			   double emitf(int, int, double),
-			   double stepf(int, int, double, double));
+			   double initf(int, int *), 
+			   double emitf(int, int, double, int *),
+			   double stepf(int, int, double, double, int *));
 
 /**********************************************************************
  * 
@@ -143,9 +143,9 @@ void calc_genoprob_special(int n_ind, int n_pos, int n_gen, int *geno,
 void sim_geno(int n_ind, int n_pos, int n_gen, int n_draws,
 	      int *geno, double *rf, double *rf2, 
 	      double error_prob, int *draws,
-	      double initf(int), 
-	      double emitf(int, int, double),
-	      double stepf(int, int, double, double));
+	      double initf(int, int *), 
+	      double emitf(int, int, double, int *),
+	      double stepf(int, int, double, double, int *));
 
 
 /**********************************************************************
@@ -197,10 +197,10 @@ void sim_geno(int n_ind, int n_pos, int n_gen, int n_draws,
    but in the alpha's and beta's, we use 0, 1, ... */
 
 void est_map(int n_ind, int n_mar, int n_gen, int *geno, double *rf, 
-	     double *rf2, double error_prob, double initf(int), 
-	     double emitf(int, int, double),
-	     double stepf(int, int, double, double), 
-	     double nrecf1(int, int), double nrecf2(int, int), 
+	     double *rf2, double error_prob, double initf(int, int *), 
+	     double emitf(int, int, double, int *),
+	     double stepf(int, int, double, double, int *), 
+	     double nrecf1(int, int, double, int*), double nrecf2(int, int, double, int*), 
 	     double *loglik, int maxit, double tol, int sexsp, 
 	     int verbose);
 
@@ -246,11 +246,11 @@ void est_map(int n_ind, int n_mar, int n_gen, int *geno, double *rf,
    but in the alpha's and beta's, we use 0, 1, ... */
 
 void argmax_geno(int n_ind, int n_pos, int n_gen, int *geno, 
-		   double *rf, double *rf2, 
-		   double error_prob, int *argmax, 
-		   double initf(int), 
-		   double emitf(int, int, double),
-		   double stepf(int, int, double, double));
+		 double *rf, double *rf2, 
+		 double error_prob, int *argmax, 
+		 double initf(int, int *), 
+		 double emitf(int, int, double, int*),
+		 double stepf(int, int, double, double, int *));
 
 /**********************************************************************
  * 
@@ -313,8 +313,8 @@ void calc_errorlod(int n_ind, int n_mar, int n_gen, int *geno,
  **********************************************************************/
 
 void est_rf(int n_ind, int n_mar, int *geno, double *rf, 
-	    double erec(int, int, double), 
-	    double logprec(int, int, double), 
+	    double erec(int, int, double, int *), 
+	    double logprec(int, int, double, int *), 
 	    int maxit, double tol, int meioses_per);
 
 /**********************************************************************
@@ -366,9 +366,9 @@ void calc_pairprob(int n_ind, int n_pos, int n_gen, int *geno,
 		   double *rf, double *rf2, 
 		   double error_prob, double *genoprob, 
 		   double *pairprob, 
-		   double initf(int), 
-		   double emitf(int, int, double),
-		   double stepf(int, int, double, double));
+		   double initf(int, int *), 
+		   double emitf(int, int, double, int *),
+		   double stepf(int, int, double, double, int *));
 
 /**********************************************************************
  * 
@@ -427,8 +427,8 @@ void R_calc_pairprob_condindep(int *n_ind, int *n_pos, int *n_gen,
 /* Note: true genotypes coded as 1, 2 */
 
 void marker_loglik(int n_ind, int n_gen, int *geno, 
-		   double error_prob, double initf(int), 
-		   double emitf(int, int, double),
+		   double error_prob, double initf(int, int *), 
+		   double emitf(int, int, double, int *),
 		   double *loglik);
 
 /* end of hmm_main.h */
