@@ -47,12 +47,12 @@
 #include "hmm_ri4self.h"
 #include "hmm_bc.h"
 
-double init_ri4self(int true_gen)
+double init_ri4self(int true_gen, int *cross_scheme)
 {
   return(-2.0*M_LN2);
 }
 
-double emit_ri4self(int obs_gen, int true_gen, double error_prob)
+double emit_ri4self(int obs_gen, int true_gen, double error_prob, int *cross_scheme)
 {
   if(obs_gen==0) return(0.0);
   if(obs_gen & (1 << (true_gen-1))) return(log(1.0-error_prob));
@@ -60,7 +60,7 @@ double emit_ri4self(int obs_gen, int true_gen, double error_prob)
 }
     
   
-double step_ri4self(int gen1, int gen2, double rf, double junk) 
+double step_ri4self(int gen1, int gen2, double rf, double junk, int *cross_scheme) 
 {
   if(gen1 == gen2) 
     return(log(1.0-rf)-log(1.0+2.0*rf));
@@ -70,7 +70,7 @@ double step_ri4self(int gen1, int gen2, double rf, double junk)
 
 
 /* this is needed for est.map; estimated recombination fractions on the RIL scale */
-double step_special_ri4self(int gen1, int gen2, double rf, double junk) 
+double step_special_ri4self(int gen1, int gen2, double rf, double junk, int *cross_scheme) 
 {
   if(gen1 == gen2) 
     return(log(1.0-rf));
@@ -129,7 +129,7 @@ void est_map_ri4self(int *n_ind, int *n_mar, int *geno, double *rf,
 }
 
 /* expected no. recombinants */
-double nrec2_ri4self(int obs1, int obs2, double rf)
+double nrec2_ri4self(int obs1, int obs2, double rf, int *cross_scheme)
 {
   int n1, n2, n12, nr, and, i, nstr=4;
 
@@ -150,7 +150,7 @@ double nrec2_ri4self(int obs1, int obs2, double rf)
 }
 
 /* log [joint probability * 8] */
-double logprec_ri4self(int obs1, int obs2, double rf)
+double logprec_ri4self(int obs1, int obs2, double rf, int *cross_scheme)
 {
   int n1, n2, n12, nr, and, i, nstr=4;
   
