@@ -48,12 +48,12 @@
 #include "hmm_ri8sib.h"
 #include "hmm_bc.h"
 
-double init_ri8sib(int true_gen)
+double init_ri8sib(int true_gen, int *cross_scheme)
 {
   return(-3.0*M_LN2); /* log(1/8) */
 }
 
-double emit_ri8sib(int obs_gen, int true_gen, double error_prob)
+double emit_ri8sib(int obs_gen, int true_gen, double error_prob, int *cross_scheme)
 {
   if(obs_gen==0) return(0.0);
   if(obs_gen & (1 << (true_gen-1))) return(log(1.0-error_prob));
@@ -61,7 +61,7 @@ double emit_ri8sib(int obs_gen, int true_gen, double error_prob)
 }
     
   
-double step_ri8sib(int gen1, int gen2, double rf, double junk) 
+double step_ri8sib(int gen1, int gen2, double rf, double junk, int *cross_scheme) 
 {
   if(gen1 == gen2) 
     return(log(1.0-rf)-log(1.0+6.0*rf));
@@ -71,7 +71,7 @@ double step_ri8sib(int gen1, int gen2, double rf, double junk)
 
 
 /* this is needed for est.map; estimated recombination fractions on the RIL scale */
-double step_special_ri8sib(int gen1, int gen2, double rf, double junk) 
+double step_special_ri8sib(int gen1, int gen2, double rf, double junk, int *cross_scheme) 
 {
   if(gen1 == gen2) 
     return(log(1.0-rf));
@@ -131,7 +131,7 @@ void est_map_ri8sib(int *n_ind, int *n_mar, int *geno, double *rf,
 
 
 /* expected no. recombinants */
-double nrec2_ri8sib(int obs1, int obs2, double rf)
+double nrec2_ri8sib(int obs1, int obs2, double rf, int *cross_scheme)
 {
   int n1, n2, n12, nr, and, i, nstr=8;
 
@@ -152,7 +152,7 @@ double nrec2_ri8sib(int obs1, int obs2, double rf)
 }
 
 /* log [joint probability * 8] */
-double logprec_ri8sib(int obs1, int obs2, double rf)
+double logprec_ri8sib(int obs1, int obs2, double rf, int *cross_scheme)
 {
   int n1, n2, n12, nr, and, i, nstr=8;
   
