@@ -2,9 +2,9 @@
  * 
  * scanone_em.h
  *
- * copyright (c) 2001-6, Karl W Broman
+ * copyright (c) 2001-2010, Karl W Broman
  *
- * last modified Feb, 2006
+ * last modified Jul, 2010
  * first written Nov, 2001
  *
  *     This program is free software; you can redistribute it and/or
@@ -42,7 +42,8 @@ void R_scanone_em(int *n_ind, int *n_pos, int *n_gen,
 		  double *intcov, int *n_intcov, double *pheno,
 		  double *weights,
 		  double *result, int *std_start, double *start,
-		  int *maxit, double *tol, int *verbose);
+		  int *maxit, double *tol, int *verbose,
+		  int *ind_noqtl);
 
 /**********************************************************************
  * 
